## cmk-dev-site without vpn
<!--
type: bugfix
scope: all
affected: all
-->

This resolves the problem of working without a vpn by introducing faster test for checking vpn.
Additionally, the bug for resolving package hash on tstbuilds server has resolved.
